package com.ic.modules.auth.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ic.annotation.AuditLogs;
import com.ic.constant.DBConfig;
import com.ic.constant.StatusCode;
import com.ic.exception.ResourceNotFoundException;
import com.ic.modules.auth.model.Configurations;
import com.ic.modules.auth.model.FycMapping;
import com.ic.modules.auth.payload.ConfigurationsDto;
import com.ic.modules.auth.payload.fycDto;
import com.ic.modules.auth.payload.request.ApiResponse;
import com.ic.modules.auth.service.ConfigurationsService;
import com.ic.modules.auth.service.FycMappingService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController 
@RequestMapping("/api/v1")
@Api(description = "Configurations management API")

public class FycMappingController {
	
	  @Autowired
	  FycMappingService fycMappingService;
	 
	    @Autowired
	    DBConfig DBConfig;
	    @PostMapping("/fycmapping/get")
	    @ApiOperation("Get all fyc mapping list")
	    @AuditLogs(isRequest = true, isResponse = true,service="Get fyc")
	    
	    //Neel – 20-Apr-2020 – Tata - Fyc mapping – Added function for fetch all data of fyc from table
	    public ResponseEntity<?> getAllFycMappings(){
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Fyc List", fycMappingService.findAll().stream().map(FycMapping -> new fycDto(FycMapping))), HttpStatus.OK);
	    }
	    
	    @PostMapping("/fycmapping/create")
	    @ApiOperation("Create fycmapping")
	    @AuditLogs(isRequest = true, isResponse = true,service="Create fycmapping")
	    public ResponseEntity<?> createFycmapping(@RequestBody fycDto fycMapping) {
	    	System.out.println("in fyc contrroler");
	    	System.out.println("in fycmapping");
	    	FycMapping fyc = null;
	    	try {
	    		fyc =  fycMappingService.save(fycMapping,true);

	    	}catch(ResourceNotFoundException e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "fycmapping Not found", fyc.getId()), HttpStatus.NOT_FOUND);
	    	}catch(Exception e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "fycmapping creation failed", fyc.getId()), HttpStatus.BAD_REQUEST);
	    	}
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Configurations added successfully", new fycDto(fyc)), HttpStatus.OK);
	    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
	    }
	    
	    @PostMapping("/fycmapping/update")
	    @ApiOperation("update fycmapping")
	    @AuditLogs(isRequest = true, isResponse = true,service="Create fycmapping")
	    public ResponseEntity<?> updateFycmapping(@RequestBody fycDto fycMapping) { //Neel – 20-Apr-2020 – Tata - Fyc mapping – Added function for Store  data of fyc from table
	    	System.out.println("in fyc contrroler");
	    	System.out.println("in fycmapping");
	    	FycMapping fycupdate = null;
	    	try {
	    		fycupdate =  fycMappingService.save(fycMapping,false);

	    	}catch(ResourceNotFoundException e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "fycmapping Not found", fycupdate.getId()), HttpStatus.NOT_FOUND);
	    	}catch(Exception e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "fycmapping creation failed", fycupdate.getId()), HttpStatus.BAD_REQUEST);
	    	}
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Configurations added successfully", new fycDto(fycupdate)), HttpStatus.OK);
	    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
	    }

}
