package com.ic.modules.auth.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ic.annotation.AuditLogs;
import com.ic.constant.LeaderCalcConfig;
import com.ic.constant.StatusCode;
import com.ic.exception.ResourceNotFoundException;
import com.ic.modules.auth.model.L1slabsMapping;
import com.ic.modules.auth.model.L2slabsMapping;
import com.ic.modules.auth.model.MDBMapping;
import com.ic.modules.auth.model.MpbMapping;
import com.ic.modules.auth.model.MsaMapping;
import com.ic.modules.auth.payload.L1slabsDto;
import com.ic.modules.auth.payload.L2slabsDto;
import com.ic.modules.auth.payload.MDBDto;
import com.ic.modules.auth.payload.MsaDto;
import com.ic.modules.auth.payload.mpbDto;
import com.ic.modules.auth.payload.request.ApiResponse;

import com.ic.modules.auth.service.MDBMappingService;
import com.ic.modules.auth.service.MsaMappingService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController 
@RequestMapping("/api/v1")
@Api(description = "MSA maping management API")

public class MsaMappingController {

	@Autowired
	MsaMappingService msaMappingService;
	
	LeaderCalcConfig LeaderCalcConfig;
    @PostMapping("/msamapping/get")
    @ApiOperation("Get all msa mapping list")
    @AuditLogs(isRequest = true, isResponse = true,service="Get msa")
    public ResponseEntity<?> getAllMDBMappings( ){
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "MSA List", msaMappingService.findAll().stream().map(MSAMapping -> new MsaDto(MSAMapping))), HttpStatus.OK);
    }
    
    @PostMapping("/msamapping/create")
    @ApiOperation("Create msamapping")
    @AuditLogs(isRequest = true, isResponse = true,service="Create msamapping")
    public ResponseEntity<?> createMsamapping(@RequestBody MsaDto msaMapping) {
    	System.out.println("in mpb contrroler");
    	System.out.println("in mpbmapping");
    	MsaMapping msa = null;
    	try {
    		msa =  msaMappingService.save(msaMapping,true);

    	}catch(ResourceNotFoundException e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "msamapping Not found", msa.getId()), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "msamapping creation failed", msa.getId()), HttpStatus.BAD_REQUEST);
    	}
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "msa mapping added successfully", new MsaDto(msa)), HttpStatus.OK);
    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }
	
    
    @PostMapping("/msamapping/update")
    @ApiOperation("Create msamapping")
    @AuditLogs(isRequest = true, isResponse = true,service="update msamapping")
    public ResponseEntity<?>updateMsamapping(@RequestBody MsaDto msaMapping) {
    	System.out.println("in mpb contrroler");
    	System.out.println("in mpbmapping");
    	MsaMapping msa = null;
    	try {
    		msa =  msaMappingService.save(msaMapping,false);

    	}catch(ResourceNotFoundException e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "msamapping Not found", msa.getId()), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "msamapping updation failed", msa.getId()), HttpStatus.BAD_REQUEST);
    	}
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "msa mapping updated successfully", new MsaDto(msa)), HttpStatus.OK);
    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }
}
